@@ -13,7 +13,6 @@ class Bronze(DataLake):
                          database, target, origin)
         self.initialize_variables()
 
-
     def merge(self):
         try:
             if self.table_exist:
@@ -38,4 +37,7 @@ class Bronze(DataLake):
         self.colums_validate_merge = self.colums_validate_merge_param.split(',')
 
     def load_data(self, input_data):
-        self.events = self.spark.read.parquet(input_data)
\ No newline at end of file
+        self.events = self.spark.read.parquet(input_data)
+
+    def create_json_columns_pass(self):
+        pass
