@@ -6,22 +6,24 @@ from delta_lake.Util import Util
 class TestBronze:
 
     def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                 storage_silver, input_data_param, input_data_param_v1, input_data_param_v2, input_data_param_v3,
+                 storage_silver, input_data_param_v1, input_data_param_v2, input_data_param_v3, mount_data_param,
                  colums_validate_merge_param, new_name, database, target, origin, colum_filter, value_filter,
-                 colum_validate_data, value_validate_data):
+                 colum_validate_data, value_validate_data, number_items_valide_v1, number_items_valide_v2):
         self.util = Util()
         self.colum_filter = colum_filter
         self.value_filter = value_filter
         self.colum_validate_data = colum_validate_data
         self.value_validate_data = value_validate_data
+        self.number_items_valide_v1 = number_items_valide_v1
+        self.number_items_valide_v2 = number_items_valide_v2
         self.delta_lake_v1 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
-                                    storage_bronze, storage_silver, input_data_param, input_data_param_v1,
+                                    storage_bronze, storage_silver, input_data_param_v1, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
         self.delta_lake_v2 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
-                                    storage_bronze, storage_silver, input_data_param, input_data_param_v2,
+                                    storage_bronze, storage_silver, input_data_param_v2, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
         self.delta_lake_v3 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
-                                    storage_bronze, storage_silver, input_data_param, input_data_param_v3,
+                                    storage_bronze, storage_silver, input_data_param_v3, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
 
     def test_bronze(self):
@@ -33,7 +35,7 @@ class TestBronze:
         self.delta_lake_v1.merge()
         df = self.spark.delta_lake_v1.sql("select * from {0}.{1}").format(self.delta_lake_v1.database,
                                                                           self.delta_lake_v1.table_name)
-        assert df.count() == 5
+        assert df.count() == self.number_items_valide_v1
 
         self.delta_lake_v2.initialize_config_storage()
         self.delta_lake_v2.validate_tables()
@@ -43,7 +45,7 @@ class TestBronze:
         self.delta_lake_v2.merge()
         df = self.delta_lake_v2.spark.sql("select * from {0}.{1}").format(self.delta_lake_v1.database,
                                                                           self.delta_lake_v1.table_name)
-        assert df.count() == 11
+        assert df.count() == self.number_items_valide_v2
 
         self.delta_lake_v3.initialize_config_storage()
         self.delta_lake_v3.validate_tables()
