@@ -34,7 +34,3 @@ class TestDataLake:
                                                                           self.delta_lake.target,
                                                                           self.delta_lake.new_name)
 
-    def test_create_json_columns_pass(self):
-        self.delta_lake.create_json_columns_pass()
-        assert self.delta_lake.json_load_insert_values == json.loads(const.json_colum_test)
-
